==> haskell-tagstream-conduit-0.5.6-505-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-1uACjTwneom6hMSs01E4FA
key:                  tagstream-conduit-0.5.6-1uACjTwneom6hMSs01E4FA
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  46f3a75486ccf2b36c04f5fb59bc75a1
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagstream-conduit
hs-libraries:         HStagstream-conduit-0.5.6-1uACjTwneom6hMSs01E4FA
depends:
    attoparsec-0.14.4-DYbgeBOmAIRHL8NoYiOyFW base-4.17.2.1
    blaze-builder-0.4.4-1ntb6RP4OewIlLWEkSeIAR bytestring-0.11.5.3
    case-insensitive-1.2.1.0-JVWVUVinOoKLKsx1rHKuw7
    conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    conduit-extra-1.3.8-CgVZWFLveL3JOQpGK40p1j
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP text-2.0.2
    transformers-0.5.6.2 xml-conduit-1.9.1.4-4j2T32Yc9L746h6qu9IdEP

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagstream-conduit-0.5.6-524-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-ALirCNdmGwXIsyUyEIQVRh
key:                  tagstream-conduit-0.5.6-ALirCNdmGwXIsyUyEIQVRh
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  617c42f4fb391116e30891965eebbaff
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagstream-conduit
hs-libraries:         HStagstream-conduit-0.5.6-ALirCNdmGwXIsyUyEIQVRh
depends:
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y base-4.17.2.1
    blaze-builder-0.4.4.1-1AsqmJqbexUDW45IoYp4gz bytestring-0.11.5.3
    case-insensitive-1.2.1.0-4psXWcL2Or6Ff92NkDcfKY
    conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    conduit-extra-1.3.8-1hrV1nPRDhE45dAx9zvo6P
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl text-2.0.2
    transformers-0.5.6.2 xml-conduit-1.9.1.4-93p77c2FG7W9C5BkdNl9oF

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
